from machine import I2C, Pin
from ssd1306 import SSD1306_I2C
import ufont
from time import sleep

i2c = I2C(scl = Pin(22), sda = Pin(21))
display = SSD1306_I2C(128, 64, i2c)
font = ufont.BMFont('unifont-14-12917-16.v3.bmf')

# 最簡單的顯示 '你好'
font.text(display, '你好', 0, 0, show = True)
sleep(1)

# 如果想讓文字顯示在螢幕正中間，可以通過指定文本左上角位置來修改顯示位置
font.text(display, '妳好', 48, 16, show = True)
sleep(1)

# 此時你會發現：上一次顯示顯示的文字不會消失。因為沒有指定清屏參數：`clear=True`
font.text(display, 'Hello python! 你好', 24, 16, show=True, clear=True)
sleep(1)

# 中文的寬度大概是字母的兩倍，如果你需要等寬，可以指定參數 `half_char=False`
font.text(display, 'HELLO', 32, 16, show = True, clear = True, half_char = False)
sleep(1)

# 顯示的文字如果很長，會超出螢幕邊界，需要指定參數 `auto_wrap=True` 來自動換行
words = '他日若遂凌云志，敢笑黄巢不丈夫!'
font.text(display, words, 0, 8, show = True, clear = True, auto_wrap = True)
sleep(1)

# 添加 `line_spacing: int` 參數來調整行間距，此處指定 8 個像素
font.text(display, words, 0, 8, show = True, clear = True, auto_wrap = True, line_spacing = 8)
sleep(1)

# 調整字體大小，可以指定 `font_size: int` 參數。注意：這會嚴重增加執行時間
font.text(display, 'T:15℃', 24, 8, font_size = 32, show = True, clear = True)
sleep(1)